# DEFAULT_FILE_STORAGE = "storages.backends.s3boto3.S3Boto3Storage"
AWS_ACCESS_KEY_ID = "AKIASSAHM44JUOBILO2V"
AWS_SECRET_ACCESS_KEY = "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"
AWS_STORAGE_BUCKET_NAME = "artur-testing-1"
AWS_QUERYSTRING_AUTH = True
